OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given web address is not a valid URL" : "L'indirizzo web specifico non è un URL valido",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given legal notice address is not a valid URL" : "L'indirizzo delle specifiche note legali non è un URL valido",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given privacy policy address is not a valid URL" : "L'indirizzo dello specifico criterio di riservatezza non è un URL valido",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "Invalid setting key" : "Voce di impostazione non valida",
    "Saved" : "Salvato",
    "Invalid app given" : "Applicazione non valida",
    "Invalid type for setting \"defaultApp\" given" : "Tipo per l'impostazione \"defaultApp\" non valido",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Aspetto e accessibilità",
    "PHP Imagick module" : "Modulo Imagick PHP",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Il modulo PHP \"imagick\" non è attivato sebbene l'applicazione dei temi lo sia. Affinché la generazione di favicon funzioni bene, devi installare ed attivare questo modulo.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Al modulo \"imagick\" di PHP manca il supporto SVG. Per una migliore compatibilità si consiglia di installarlo.",
    "Dark theme with high contrast mode" : "Tema scuro con modalità di contrasto elevato",
    "Enable dark high contrast mode" : "Abilita la modalità scuro ad alto contrasto",
    "Similar to the high contrast mode, but with dark colours." : "Simile alla modalità a contrasto elevato, ma con colori scuri.",
    "Dark theme" : "Tema scuro",
    "Enable dark theme" : "Abilita il tema scuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema scuro per alleviare la vista riducendo la luminosità e la brillantezza generale.",
    "System default theme" : "Tema predefinito del sistema",
    "Enable the system default" : "Abilita predefinito del sistema",
    "Using the default system appearance." : "Utilizzo dell'aspetto di sistema predefinito.",
    "Dyslexia font" : "Carattere per dislessici",
    "Enable dyslexia font" : "Abilita il carattere per dislessici",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic è un carattere libero progettato per mitigare alcuni dei comuni errori di lettura causati dalla dislessia.",
    "High contrast mode" : "Modalità ad alto contrasto",
    "Enable high contrast mode" : "Abilita la modalità ad alto contrasto",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Una modalità ad alto contrasto per semplificare la tua navigazione. La qualità visiva sarà ridotta per incrementare la chiarezza.",
    "Light theme" : "Tema chiaro",
    "Enable the default light theme" : "Abilita il tema chiaro predefinito",
    "The default light appearance." : "L'aspetto del tema chiaro predefinito.",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Could not set global default apps" : "Impossibile impostare le applicazioni predefinite globali",
    "Navigation bar settings" : "Impostazioni barra di navigazione",
    "Default app" : "Applicazione predefinita",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'applicazione predefinita è quella che viene aperta dopo l'accesso o quando si fa clic sul logo nel menu.",
    "Use custom default app" : "Usa applicazione predefinita personalizzata",
    "Global default app" : "Applicazione predefinita globale",
    "Global default apps" : "Applicazioni predefinite globali",
    "Default app priority" : "Priorità applicazione predefinita",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Se un'applicazione non è abilitata per un utente, viene usata quella successiva con priorità più bassa.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Name" : "Nome",
    "Web link" : "Collegamento web",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criteri di riservatezza",
    "Background and color" : "Sfondo e colore",
    "Primary color" : "Colore primario",
    "Background color" : "Colore di sfondo",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Background image" : "Immagine di sfondo",
    "Favicon" : "Favicon",
    "Logo" : "Logo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Sebbene tu possa selezionare e personalizzare la tua istanza, gli utenti possono cambiare il loro sfondo e colore. Se vuoi forzare la tua personalizzazione, puoi attivare questo.",
    "Disable user theming" : "Disattiva temi utente",
    "Current selected app: {app}, position {position} of {total}" : "Applicazione attualmente selezionata: {app}, posizione {position} di {total}",
    "Move up" : "Sposta su",
    "Move down" : "Sposta giù",
    "Theme selection is enforced" : "La selezione del tema è obbligata",
    "Could not set the app order" : "Impossibile impostare l'ordine delle applicazioni",
    "Could not reset the app order" : "Impossibile ripristinare l'ordine delle applicazioni",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Puoi configurare l'ordine delle applicazioni usato per la barra di navigazione. La prima voce sarà l'applicazione predefinita, aperta dopo l'accesso o quando si fa clic sul logo.",
    "The default app can not be changed because it was configured by the administrator." : "L'applicazione predefinita non può essere cambiata perché è stata configurata dall'amministratore.",
    "The app order was changed, to see it in action you have to reload the page." : "L'ordine delle applicazioni è stato cambiato, per vedere le modifiche devi ricaricare la pagina.",
    "Reset default app order" : "Ripristina ordine predefinito delle applicazioni",
    "Select a background from your files" : "Seleziona uno sfondo dai tuoi file",
    "Select background" : "Seleziona sfondo",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Lo sfondo può essere impostato ad un'immagine dal set predefinito, un'immagine caricata a mano, o un colore unico.",
    "Custom background" : "Sfondo personalizzato",
    "Plain background" : "Sfondo semplice",
    "Default background" : "Sfondo predefinito",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In alcuni casi le scorciatoie da tastiera possono interferire con gli strumenti di accessibilità. Per concentrarti correttamente sullo strumento, è possibile disattivare tutte le scorciatoie da tastiera. Verranno disattivate anche tutte le scorciatoie disponibili nelle applicazioni.",
    "Disable all keyboard shortcuts" : "Disattiva tutte le scorciatoie da tastiera",
    "Could not set primary color" : "Impossibile impostare il colore primario",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Imposta un colore primario per evidenziare elementi importanti. Il colore usato per elementi come pulsanti principali può essere leggermente diverso, dato che viene regolato per soddisfare i requisiti di accessibilità.",
    "Reset primary color" : "Ripristina colore primario",
    "Reset to default" : "Ripristina valori predefiniti",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accessibilità universale è molto importante per noi. Seguiamo gli standard web e verifichiamo che tutto sia utilizzabile anche senza mouse e con software di assistenza come gli screen reader. Il nostro obiettivo è quello di essere conformi alle {linkstart}Linee guida per l'accessibilità dei contenuti web{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se trovi qualsiasi problema, non esitare a segnalarlo sul {issuetracker}nostro sistema di segnalazione dei bug{linkend}. E se vuoi partecipare, unisciti alla {designteam}nostra squadra di progettazione{linkend}!",
    "Unable to apply the setting." : "Impossibile applicare l'impostazione.",
    "Appearance and accessibility settings" : "Impostazioni di aspetto e accessibilità",
    "Misc accessibility options" : "Altre opzioni di accessibilità ",
    "Enable blur background filter (may increase GPU load)" : "Abilita filtro di sfocamento dello sfondo (può aumentare il carico sulla GPU)",
    "Customization has been disabled by your administrator" : "La personalizzazione è stata disattivata dall'amministratore",
    "Disable-user-theming should be true or false" : "Disattiva-temi-utente deve essere true o false",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Il colore primario è usato per evidenziare elementi, come pulsanti importanti. Può essere regolato un po' a seconda dello schema di colori attuale.",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Upload new favicon" : "Carica nuova favicon",
    "User settings" : "Impostazioni utente",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Al posto di un'immagine, puoi anche configurare un colore di sfondo. Se usi un'immagine di sfondo, cambiare questo colore influenzerà il colore delle icone dei menu.",
    "Upload new logo" : "Carica nuovo logo",
    "Upload new background and login image" : "Carica nuova immagine di sfondo e di accesso",
    "Background and login image" : "Immagine di sfondo e di accesso",
    "Advanced options" : "Opzioni avanzate",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione ImageMagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accesso universale è molto importante per noi. Seguiamo gli standard web e cerchiamo di rendere tutto utilizzabile anche senza mouse, e programmi di assistenza come i lettori dello schermo. Il nostro obiettivo è la compatibilità con la {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA. ",
    ". Unable to apply the setting." : ". Impossibile applicare l'impostazione.",
    "No background has been selected" : "Nessuno sfondo selezionato",
    "Select a custom color" : "Seleziona un colore personalizzato",
    "Upload" : "Carica"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
